@@ -16,11 +16,9 @@ import Data.Word
 import Data.Int
 import qualified System.Time as ST
 import Data.Time
-import Data.Time.Clock
 import Data.Time.Clock.POSIX
-import System.Locale
+import Database.HDBC.Locale (defaultTimeLocale, iso8601DateFormat)
 import Data.Ratio
-import Control.Monad.Error
 import Data.Convertible
 import Data.Fixed
 
@@ -299,8 +297,8 @@ instance Convertible SqlValue BSL.ByteString where
 
 instance Convertible Int SqlValue where
     safeConvert x = 
-        do i <- ((safeConvert x)::ConvertResult Int32)
-           return $ SqlInt32 i
+        do i <- ((safeConvert x)::ConvertResult Int64)
+           return $ SqlInt64 i
 instance Convertible SqlValue Int where
     safeConvert (SqlString x) = read' x
     safeConvert (SqlByteString x) = (read' . BUTF8.toString) x
